/* spice-display.c generated by valac 0.18.0.79-04df6, the Vala compiler
 * generated from spice-display.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <spice-client.h>
#include <spice-widget.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <libxml/uri.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;
typedef struct _BoxesSpiceDisplayPrivate BoxesSpiceDisplayPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_SpiceUsbDevice_free0(var) ((var == NULL) ? NULL : (var = (_vala_SpiceUsbDevice_free (var), NULL)))
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block52Data Block52Data;
typedef struct _Block53Data Block53Data;
typedef struct _Block54Data Block54Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 0
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag flags);
};

struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_inputs) (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag flags);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesSpiceDisplay {
	BoxesDisplay parent_instance;
	BoxesSpiceDisplayPrivate * priv;
};

struct _BoxesSpiceDisplayClass {
	BoxesDisplayClass parent_class;
};

struct _BoxesSpiceDisplayPrivate {
	SpiceSession* session;
	SpiceGtkSession* gtk_session;
	SpiceAudio* audio;
	gulong channel_new_id;
	gulong channel_destroy_id;
	BoxesBoxConfigSyncProperty* display_sync_properties;
	gint display_sync_properties_length1;
	gint _display_sync_properties_size_;
	BoxesBoxConfigSyncProperty* gtk_session_sync_properties;
	gint gtk_session_sync_properties_length1;
	gint _gtk_session_sync_properties_size_;
	gboolean connected;
	gboolean closed;
	gboolean _resize_guest;
	SpiceMainChannel* main_channel;
	gulong main_event_id;
	gulong main_mouse_mode_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _Block52Data {
	int _ref_count_;
	BoxesSpiceDisplay * self;
	SpiceDisplay* display;
};

struct _Block53Data {
	int _ref_count_;
	BoxesSpiceDisplay * self;
	SpiceUsbDeviceManager* manager;
};

struct _Block54Data {
	int _ref_count_;
	Block53Data * _data53_;
	SpiceUsbDevice* dev;
	GtkSwitch* dev_toggle;
};


static gpointer boxes_spice_display_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
#define BOXES_SPICE_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayPrivate))
enum  {
	BOXES_SPICE_DISPLAY_DUMMY_PROPERTY,
	BOXES_SPICE_DISPLAY_PROTOCOL,
	BOXES_SPICE_DISPLAY_URI,
	BOXES_SPICE_DISPLAY_CA_CERT,
	BOXES_SPICE_DISPLAY_RESIZE_GUEST
};
static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self);
static void _vala_BoxesBoxConfigSyncProperty_array_free (BoxesBoxConfigSyncProperty* array, gint array_length);
static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n);
gboolean boxes_spice_display_get_resize_guest (BoxesSpiceDisplay* self);
BoxesSpiceDisplay* boxes_spice_display_new (BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port);
BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port);
BoxesDisplay* boxes_display_construct (GType object_type);
void boxes_display_set_config (BoxesDisplay* self, BoxesBoxConfig* value);
BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesBoxConfig* config, const gchar* uri);
BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesBoxConfig* config, const gchar* uri);
static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n);
static void ___lambda87_ (BoxesSpiceDisplay* self, gint status);
void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value);
static void ____lambda87__spice_display_mouse_grab (SpiceDisplay* _sender, gint grabbed, gpointer self);
BoxesBoxConfig* boxes_display_get_config (BoxesDisplay* self);
static gboolean boxes_spice_display_has_usb_device_connected (BoxesSpiceDisplay* self);
static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self);
static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self);
static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base);
static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable);
static void boxes_spice_display_real_set_enable_inputs (BoxesDisplay* base, GtkWidget* widget, gboolean enable);
static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error);
static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static void boxes_spice_display_real_connect_it (BoxesDisplay* base, GError** error);
static void ___lambda88_ (BoxesSpiceDisplay* self, SpiceChannel* channel);
static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event);
static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self);
static void ___lambda89_ (BoxesSpiceDisplay* self);
void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value);
static void ____lambda89__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block52Data* block52_data_ref (Block52Data* _data52_);
static void block52_data_unref (void * _userdata_);
void boxes_display_access_start (BoxesDisplay* self);
static void ___lambda90_ (Block52Data* _data52_);
static void ____lambda90__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda88__spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
static void ___lambda91_ (BoxesSpiceDisplay* self, SpiceChannel* channel);
void boxes_display_access_finish (BoxesDisplay* self);
static void ____lambda91__spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
const gchar* boxes_display_get_password (BoxesDisplay* self);
static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base);
void boxes_display_set_need_password (BoxesDisplay* self, gboolean value);
static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page, PropertyCreationFlag flags);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static Block53Data* block53_data_ref (Block53Data* _data53_);
static void block53_data_unref (void * _userdata_);
static Block54Data* block54_data_ref (Block54Data* _data54_);
static void block54_data_unref (void * _userdata_);
static void _________lambda92_ (Block54Data* _data54_);
static void ___lambda93_ (Block54Data* _data54_, GObject* obj, GAsyncResult* res);
static void ____lambda93__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __________lambda92__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self);
void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value);
void boxes_spice_display_set_resize_guest (BoxesSpiceDisplay* self, gboolean value);
static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_spice_display____lambda94_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err);
static void __boxes_spice_display____lambda94__spice_usb_device_manager_auto_connect_failed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self);
static void _boxes_spice_display____lambda95_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err);
static void __boxes_spice_display____lambda95__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self);
static void _boxes_spice_display___lambda96_ (BoxesSpiceDisplay* self);
static void __boxes_spice_display___lambda96__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_spice_display_finalize (GObject* obj);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
static gint* _int_dup (gint* self);


static void _vala_BoxesBoxConfigSyncProperty_array_free (BoxesBoxConfigSyncProperty* array, gint array_length) {
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (array != NULL) {
#line 294 "spice-display.c"
		int i;
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			boxes_box_config_sync_property_destroy (&array[i]);
#line 300 "spice-display.c"
		}
	}
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_free (array);
#line 305 "spice-display.c"
}


static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	BoxesUIState _tmp2_;
	BoxesUIState _tmp3_;
	gboolean _tmp7_;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_app_app;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp1_);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp3_ == BOXES_UI_STATE_PROPERTIES) {
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = TRUE;
#line 327 "spice-display.c"
	} else {
		BoxesApp* _tmp4_;
		BoxesUIState _tmp5_;
		BoxesUIState _tmp6_;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = boxes_app_app;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp4_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _tmp5_;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp6_ == BOXES_UI_STATE_DISPLAY;
#line 340 "spice-display.c"
	}
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp0_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp7_) {
#line 346 "spice-display.c"
		GtkWidget* _tmp8_ = NULL;
		SpiceDisplay* display;
		gboolean _tmp9_ = FALSE;
		BoxesApp* _tmp10_;
		BoxesUIState _tmp11_;
		BoxesUIState _tmp12_;
		SpiceDisplay* _tmp14_;
		gboolean _tmp15_;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = boxes_display_get_display ((BoxesDisplay*) self, 0);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		display = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp8_) : NULL;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = boxes_app_app;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp10_);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp12_ == BOXES_UI_STATE_DISPLAY) {
#line 367 "spice-display.c"
			gboolean _tmp13_;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp13_ = self->priv->_resize_guest;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp9_ = _tmp13_;
#line 373 "spice-display.c"
		} else {
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp9_ = FALSE;
#line 377 "spice-display.c"
		}
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = display;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp15_ = _tmp9_;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp14_, "resize-guest", _tmp15_, NULL);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 387 "spice-display.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self ? g_object_ref (self) : NULL;
#line 395 "spice-display.c"
}


static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_;
	SpiceMainChannel* _tmp1_;
	GObject* _tmp2_;
	GObject* o;
	GObject* _tmp3_;
	gulong _tmp4_;
	GObject* _tmp5_;
	gulong _tmp6_;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->main_channel;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ == NULL) {
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 416 "spice-display.c"
	}
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->main_channel;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, G_TYPE_OBJECT) ? ((GObject*) _tmp1_) : NULL);
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	o = _tmp2_;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = o;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->main_event_id;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp3_, _tmp4_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->main_event_id = (gulong) 0;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = o;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = self->priv->main_mouse_mode_id;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp5_, _tmp6_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->main_mouse_mode_id = (gulong) 0;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->main_channel);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->main_channel = NULL;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (o);
#line 446 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port) {
	BoxesSpiceDisplay * self = NULL;
	gint _tmp0_;
	gint _tmp1_;
	BoxesBoxConfig* _tmp2_;
	SpiceSession* _tmp3_;
	const gchar* _tmp4_;
	gint _tmp5_;
	gint _tmp10_;
	SpiceSession* _tmp15_;
	const gchar* _tmp16_ = NULL;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (host != NULL, NULL);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = port;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = tls_port;
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail ((_tmp0_ != 0) || (_tmp1_ != 0), NULL);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = config;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp2_);
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->session;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = host;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp3_, "host", _tmp4_, NULL);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = port;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ != 0) {
#line 487 "spice-display.c"
		SpiceSession* _tmp6_;
		gint _tmp7_;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp7_ = port;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = g_strdup_printf ("%i", _tmp7_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = _tmp8_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp6_, "port", _tmp9_, NULL);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp9_);
#line 504 "spice-display.c"
	}
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = tls_port;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp10_ != 0) {
#line 510 "spice-display.c"
		SpiceSession* _tmp11_;
		gint _tmp12_;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = self->priv->session;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = tls_port;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = g_strdup_printf ("%i", _tmp12_);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = _tmp13_;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp11_, "tls-port", _tmp14_, NULL);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp14_);
#line 527 "spice-display.c"
	}
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp15_ = self->priv->session;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp16_ = g_getenv ("BOXES_SPICE_HOST_SUBJECT");
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp15_, "cert-subject", _tmp16_, NULL);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self;
#line 537 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new (BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port) {
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct (BOXES_TYPE_SPICE_DISPLAY, config, host, port, tls_port);
#line 544 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesBoxConfig* config, const gchar* uri) {
	BoxesSpiceDisplay * self = NULL;
	BoxesBoxConfig* _tmp0_;
	SpiceSession* _tmp1_;
	const gchar* _tmp2_;
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = config;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp0_);
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->session;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = uri;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp1_, "uri", _tmp2_, NULL);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self;
#line 571 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesBoxConfig* config, const gchar* uri) {
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct_with_uri (BOXES_TYPE_SPICE_DISPLAY, config, uri);
#line 578 "spice-display.c"
}


static void ___lambda87_ (BoxesSpiceDisplay* self, gint status) {
	gint _tmp0_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = status;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_mouse_grabbed ((BoxesDisplay*) self, _tmp0_ != 0);
#line 588 "spice-display.c"
}


static void ____lambda87__spice_display_mouse_grab (SpiceDisplay* _sender, gint grabbed, gpointer self) {
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda87_ (self, grabbed);
#line 595 "spice-display.c"
}


static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n) {
	BoxesSpiceDisplay * self;
	GtkWidget* result = NULL;
	GHashTable* _tmp0_;
	gint _tmp1_;
	gconstpointer _tmp2_ = NULL;
	SpiceDisplay* _tmp3_;
	SpiceDisplay* display;
	SpiceDisplay* _tmp4_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = ((BoxesDisplay*) self)->displays;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = n;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, (gpointer) ((gintptr) _tmp1_));
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE ((GtkWidget*) _tmp2_, spice_display_get_type ()) ? ((SpiceDisplay*) ((GtkWidget*) _tmp2_)) : NULL);
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	display = _tmp3_;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = display;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp4_ == NULL) {
#line 624 "spice-display.c"
		SpiceSession* _tmp5_;
		gint _tmp6_;
		SpiceDisplay* _tmp7_;
		SpiceDisplay* _tmp8_;
		BoxesBoxConfig* _tmp9_;
		BoxesBoxConfig* _tmp10_;
		BoxesBoxConfigSyncProperty* _tmp11_;
		gint _tmp11__length1;
		SpiceDisplay* _tmp12_;
		SpiceDisplay* _tmp13_;
		GObjectClass* _tmp14_ = NULL;
		GParamSpec* _tmp15_ = NULL;
		GHashTable* _tmp17_;
		gint _tmp18_;
		SpiceDisplay* _tmp19_;
		GtkWidget* _tmp20_;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = self->priv->session;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = n;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp7_ = spice_display_new (_tmp5_, _tmp6_);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_ref_sink (_tmp7_);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		display = _tmp7_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = display;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp8_, "mouse-grab", (GCallback) ____lambda87__spice_display_mouse_grab, self, 0);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = _tmp9_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11_ = self->priv->display_sync_properties;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp11__length1 = self->priv->display_sync_properties_length1;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_box_config_sync_properties (_tmp10_, (GObject*) self, _tmp11_, _tmp11__length1);
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = display;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp12_, "scaling", TRUE, NULL);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = display;
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = G_OBJECT_GET_CLASS ((GObject*) _tmp13_);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp15_ = g_object_class_find_property (_tmp14_, "only-downscale");
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp15_ != NULL) {
#line 679 "spice-display.c"
			SpiceDisplay* _tmp16_;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp16_ = display;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_object_set ((GObject*) _tmp16_, "only-downscale", TRUE, NULL);
#line 685 "spice-display.c"
		}
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp17_ = ((BoxesDisplay*) self)->displays;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp18_ = n;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp19_ = display;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp20_ = _g_object_ref0 ((GtkWidget*) _tmp19_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_hash_table_replace (_tmp17_, (gpointer) ((gintptr) _tmp18_), _tmp20_);
#line 697 "spice-display.c"
	}
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = (GtkWidget*) display;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 703 "spice-display.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4080 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4080 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4080 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4080 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 718 "spice-display.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4081 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4081 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4081 "/home/zeenix/jhbuild/share/vala-0.20/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 730 "spice-display.c"
}


static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self) {
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return g_boxed_copy (spice_usb_device_get_type (), self);
#line 737 "spice-display.c"
}


static gpointer __vala_SpiceUsbDevice_copy0 (gpointer self) {
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self ? _vala_SpiceUsbDevice_copy (self) : NULL;
#line 744 "spice-display.c"
}


static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self) {
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_boxed_free (spice_usb_device_get_type (), self);
#line 751 "spice-display.c"
}


static gboolean boxes_spice_display_has_usb_device_connected (BoxesSpiceDisplay* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 760 "spice-display.c"
	{
		SpiceSession* _tmp0_;
		SpiceUsbDeviceManager* _tmp1_ = NULL;
		SpiceUsbDeviceManager* _tmp2_;
		SpiceUsbDeviceManager* manager;
		SpiceUsbDeviceManager* _tmp3_;
		GPtrArray* _tmp4_ = NULL;
		GPtrArray* devs;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = self->priv->session;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp1_ = spice_usb_device_manager_get (_tmp0_, &_inner_error_);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		manager = _tmp2_;
#line 129 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 779 "spice-display.c"
			goto __catch63_g_error;
		}
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = manager;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = spice_usb_device_manager_get_devices (_tmp3_);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		devs = _tmp4_;
#line 788 "spice-display.c"
		{
			gint i;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			i = 0;
#line 793 "spice-display.c"
			{
				gboolean _tmp5_;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp5_ = TRUE;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				while (TRUE) {
#line 800 "spice-display.c"
					gboolean _tmp6_;
					gint _tmp8_;
					GPtrArray* _tmp9_;
					gint _tmp10_;
					gint _tmp11_;
					GPtrArray* _tmp12_;
					gint _tmp13_;
					gconstpointer _tmp14_ = NULL;
					SpiceUsbDevice* _tmp15_;
					SpiceUsbDevice* dev;
					SpiceUsbDeviceManager* _tmp16_;
					SpiceUsbDevice* _tmp17_;
					gboolean _tmp18_ = FALSE;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp6_ = _tmp5_;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!_tmp6_) {
#line 818 "spice-display.c"
						gint _tmp7_;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp7_ = i;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						i = _tmp7_ + 1;
#line 824 "spice-display.c"
					}
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp5_ = FALSE;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp8_ = i;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp9_ = devs;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp10_ = g_ptr_array_get_length (_tmp9_);
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp11_ = _tmp10_;
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!(_tmp8_ < _tmp11_)) {
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						break;
#line 840 "spice-display.c"
					}
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp12_ = devs;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp13_ = i;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp14_ = g_ptr_array_index (_tmp12_, (guint) _tmp13_);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp15_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp14_);
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					dev = _tmp15_;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp16_ = manager;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp17_ = dev;
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp18_ = spice_usb_device_manager_is_device_connected (_tmp16_, _tmp17_);
#line 133 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (_tmp18_) {
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						result = TRUE;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						__vala_SpiceUsbDevice_free0 (dev);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_ptr_array_unref0 (devs);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_object_unref0 (manager);
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						return result;
#line 870 "spice-display.c"
					}
#line 131 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 874 "spice-display.c"
				}
			}
		}
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 882 "spice-display.c"
	}
	goto __finally63;
	__catch63_g_error:
	{
		GError* _error_ = NULL;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 894 "spice-display.c"
	}
	__finally63:
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return FALSE;
#line 905 "spice-display.c"
	}
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = FALSE;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 911 "spice-display.c"
}


static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp3_;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->closed;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (!_tmp1_) {
#line 927 "spice-display.c"
		gboolean _tmp2_ = FALSE;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = boxes_spice_display_has_usb_device_connected (self);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp2_;
#line 933 "spice-display.c"
	} else {
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = FALSE;
#line 937 "spice-display.c"
	}
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp0_;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp3_;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 945 "spice-display.c"
}


static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable) {
	BoxesSpiceDisplay * self;
	SpiceSession* _tmp0_;
	gboolean _tmp1_;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = enable;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "enable-audio", _tmp1_, NULL);
#line 961 "spice-display.c"
}


static void boxes_spice_display_real_set_enable_inputs (BoxesDisplay* base, GtkWidget* widget, gboolean enable) {
	BoxesSpiceDisplay * self;
	GtkWidget* _tmp0_;
	gboolean _tmp1_;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (widget != NULL);
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = widget;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = enable;
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp0_) : NULL, "disable-inputs", !_tmp1_, NULL);
#line 979 "spice-display.c"
}


static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error) {
	BoxesSpiceDisplay * self;
	GdkPixbuf* result = NULL;
	gint _tmp0_;
	GtkWidget* _tmp1_ = NULL;
	SpiceDisplay* display;
	SpiceDisplay* _tmp2_;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_;
	SpiceDisplay* _tmp5_;
	GdkPixbuf* _tmp6_ = NULL;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = n;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_display ((BoxesDisplay*) self, _tmp0_);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	display = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp1_) : NULL;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = display;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp2_, "ready", &_tmp3_, NULL);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _tmp3_;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (!_tmp4_) {
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		result = NULL;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return result;
#line 1016 "spice-display.c"
	}
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = display;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = spice_display_get_pixbuf (_tmp5_);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp6_;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (display);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 1028 "spice-display.c"
}


static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder) {
	BoxesSpiceDisplay * self;
	GString* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_ = NULL;
	gboolean _tmp5_;
	GString* _tmp6_;
	const gchar* _tmp7_;
	SpiceGtkSession* _tmp8_;
	SpiceMainChannel* _tmp21_;
	GError * _inner_error_ = NULL;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 162 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (builder != NULL);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = builder;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_uri ((BoxesDisplay*) self);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_string_append_printf (_tmp0_, "URI: %s\n", _tmp3_);
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp3_);
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->_resize_guest;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp5_) {
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = "yes";
#line 1067 "spice-display.c"
	} else {
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = "no";
#line 1071 "spice-display.c"
	}
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = builder;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp4_;
#line 164 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_string_append_printf (_tmp6_, "Auto resize guest: %s\n", _tmp7_);
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp8_ = self->priv->gtk_session;
#line 165 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp8_ != NULL) {
#line 1083 "spice-display.c"
		const gchar* _tmp9_ = NULL;
		SpiceGtkSession* _tmp10_;
		gboolean _tmp11_ = FALSE;
		gboolean _tmp12_;
		GString* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_ = NULL;
		SpiceGtkSession* _tmp16_;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_;
		GString* _tmp19_;
		const gchar* _tmp20_;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = self->priv->gtk_session;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp10_, "auto-usbredir", &_tmp11_, NULL);
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp12_) {
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp9_ = "yes";
#line 1106 "spice-display.c"
		} else {
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp9_ = "no";
#line 1110 "spice-display.c"
		}
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = builder;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = _tmp9_;
#line 166 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp13_, "Auto redirect USB: %s\n", _tmp14_);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = self->priv->gtk_session;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp16_, "auto-clipboard", &_tmp17_, NULL);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _tmp17_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp18_) {
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp15_ = "yes";
#line 1128 "spice-display.c"
		} else {
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp15_ = "no";
#line 1132 "spice-display.c"
		}
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp19_ = builder;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp20_ = _tmp15_;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp19_, "Auto clipboard sync: %s\n", _tmp20_);
#line 1140 "spice-display.c"
	}
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp21_ = self->priv->main_channel;
#line 169 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp21_ != NULL) {
#line 1146 "spice-display.c"
		GString* _tmp22_;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		SpiceMainChannel* _tmp25_;
		gint _tmp26_ = 0;
		gint _tmp27_;
		GString* _tmp28_;
		const gchar* _tmp29_;
		const gchar* _tmp30_ = NULL;
		SpiceMainChannel* _tmp31_;
		gboolean _tmp32_ = FALSE;
		gboolean _tmp33_;
		GString* _tmp34_;
		const gchar* _tmp35_;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp22_ = builder;
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp23_ = spice_util_get_version_string ();
#line 170 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp22_, "Spice-gtk version %s\n", _tmp23_);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp25_ = self->priv->main_channel;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp25_, "mouse-mode", &_tmp26_, NULL);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp27_ = _tmp26_;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp27_ == 1) {
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp24_ = "server";
#line 1177 "spice-display.c"
		} else {
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp24_ = "client";
#line 1181 "spice-display.c"
		}
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp28_ = builder;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp29_ = _tmp24_;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp28_, "Mouse mode: %s\n", _tmp29_);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp31_ = self->priv->main_channel;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp31_, "agent-connected", &_tmp32_, NULL);
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp33_ = _tmp32_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp33_) {
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp30_ = "connected";
#line 1199 "spice-display.c"
		} else {
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp30_ = "disconnected";
#line 1203 "spice-display.c"
		}
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp34_ = builder;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp35_ = _tmp30_;
#line 172 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp34_, "Agent: %s\n", _tmp35_);
#line 1211 "spice-display.c"
	}
	{
		SpiceSession* _tmp36_;
		SpiceUsbDeviceManager* _tmp37_ = NULL;
		SpiceUsbDeviceManager* _tmp38_;
		SpiceUsbDeviceManager* manager;
		SpiceUsbDeviceManager* _tmp39_;
		GPtrArray* _tmp40_ = NULL;
		GPtrArray* devs;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp36_ = self->priv->session;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp37_ = spice_usb_device_manager_get (_tmp36_, &_inner_error_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp38_ = _g_object_ref0 (_tmp37_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		manager = _tmp38_;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 1231 "spice-display.c"
			goto __catch64_g_error;
		}
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp39_ = manager;
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp40_ = spice_usb_device_manager_get_devices (_tmp39_);
#line 177 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		devs = _tmp40_;
#line 1240 "spice-display.c"
		{
			gint i;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			i = 0;
#line 1245 "spice-display.c"
			{
				gboolean _tmp41_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp41_ = TRUE;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				while (TRUE) {
#line 1252 "spice-display.c"
					gboolean _tmp42_;
					gint _tmp44_;
					GPtrArray* _tmp45_;
					gint _tmp46_;
					gint _tmp47_;
					GPtrArray* _tmp48_;
					gint _tmp49_;
					gconstpointer _tmp50_ = NULL;
					SpiceUsbDevice* _tmp51_;
					SpiceUsbDevice* dev;
					SpiceUsbDeviceManager* _tmp52_;
					SpiceUsbDevice* _tmp53_;
					gboolean _tmp54_ = FALSE;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp42_ = _tmp41_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!_tmp42_) {
#line 1270 "spice-display.c"
						gint _tmp43_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp43_ = i;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						i = _tmp43_ + 1;
#line 1276 "spice-display.c"
					}
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp41_ = FALSE;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp44_ = i;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp45_ = devs;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp46_ = g_ptr_array_get_length (_tmp45_);
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp47_ = _tmp46_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (!(_tmp44_ < _tmp47_)) {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						break;
#line 1292 "spice-display.c"
					}
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp48_ = devs;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp49_ = i;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp50_ = g_ptr_array_index (_tmp48_, (guint) _tmp49_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp51_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp50_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					dev = _tmp51_;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp52_ = manager;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp53_ = dev;
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_tmp54_ = spice_usb_device_manager_is_device_connected (_tmp52_, _tmp53_);
#line 180 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (_tmp54_) {
#line 1312 "spice-display.c"
						GString* _tmp55_;
						SpiceUsbDevice* _tmp56_;
						gchar* _tmp57_ = NULL;
						gchar* _tmp58_;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp55_ = builder;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp56_ = dev;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp57_ = spice_usb_device_get_description (_tmp56_, "%s %s %s at %d-%d");
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp58_ = _tmp57_;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						g_string_append_printf (_tmp55_, "USB device redirected: %s\n", _tmp58_);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_free0 (_tmp58_);
#line 1329 "spice-display.c"
					}
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 1333 "spice-display.c"
				}
			}
		}
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 1341 "spice-display.c"
	}
	goto __finally64;
	__catch64_g_error:
	{
		GError* _error_ = NULL;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 1353 "spice-display.c"
	}
	__finally64:
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 1364 "spice-display.c"
	}
}


static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self) {
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_event (self, event);
#line 1372 "spice-display.c"
}


static void ___lambda89_ (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_;
	gint _tmp1_ = 0;
	gint _tmp2_;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->main_channel;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "mouse-mode", &_tmp1_, NULL);
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 204 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp2_ != 2);
#line 1388 "spice-display.c"
}


static void ____lambda89__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda89_ (self);
#line 1395 "spice-display.c"
}


static Block52Data* block52_data_ref (Block52Data* _data52_) {
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data52_->_ref_count_);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data52_;
#line 1404 "spice-display.c"
}


static void block52_data_unref (void * _userdata_) {
	Block52Data* _data52_;
	_data52_ = (Block52Data*) _userdata_;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data52_->_ref_count_)) {
#line 1413 "spice-display.c"
		BoxesSpiceDisplay * self;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data52_->self;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data52_->display);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block52Data, _data52_);
#line 1423 "spice-display.c"
	}
}


static void ___lambda90_ (Block52Data* _data52_) {
	BoxesSpiceDisplay * self;
	SpiceDisplay* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data52_->self;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data52_->display;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "ready", &_tmp1_, NULL);
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 216 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_) {
#line 1443 "spice-display.c"
		SpiceDisplay* _tmp3_;
		gint _tmp4_ = 0;
		gint _tmp5_;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data52_->display;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp3_, "channel-id", &_tmp4_, NULL);
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _tmp4_;
#line 217 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "show", _tmp5_);
#line 1455 "spice-display.c"
	} else {
		SpiceDisplay* _tmp6_;
		gint _tmp7_ = 0;
		gint _tmp8_;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data52_->display;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp6_, "channel-id", &_tmp7_, NULL);
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 219 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "hide", _tmp8_);
#line 1468 "spice-display.c"
	}
}


static void ____lambda90__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda90_ (self);
#line 1476 "spice-display.c"
}


static void ___lambda88_ (BoxesSpiceDisplay* self, SpiceChannel* channel) {
	SpiceChannel* _tmp0_;
	gint _tmp1_ = 0;
	gint _tmp2_;
	gint id;
	SpiceChannel* _tmp3_;
	SpiceChannel* _tmp13_;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "channel-id", &_tmp1_, NULL);
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 198 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	id = _tmp2_;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = channel;
#line 200 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, spice_main_channel_get_type ())) {
#line 1501 "spice-display.c"
		SpiceChannel* _tmp4_;
		SpiceMainChannel* _tmp5_;
		SpiceMainChannel* _tmp6_;
		gulong _tmp7_ = 0UL;
		SpiceMainChannel* _tmp8_;
		gulong _tmp9_ = 0UL;
		SpiceMainChannel* _tmp10_;
		gint _tmp11_ = 0;
		gint _tmp12_;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = channel;
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, spice_main_channel_get_type ()) ? ((SpiceMainChannel*) _tmp4_) : NULL);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self->priv->main_channel);
#line 201 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->main_channel = _tmp5_;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->main_channel;
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp7_ = g_signal_connect_object ((SpiceChannel*) _tmp6_, "channel-event", (GCallback) _boxes_spice_display_main_event_spice_channel_channel_event, self, 0);
#line 202 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->main_event_id = _tmp7_;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = self->priv->main_channel;
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = g_signal_connect_object ((GObject*) _tmp8_, "notify::mouse-mode", (GCallback) ____lambda89__g_object_notify, self, 0);
#line 203 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->main_mouse_mode_id = _tmp9_;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = self->priv->main_channel;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp10_, "mouse-mode", &_tmp11_, NULL);
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 206 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp12_ != 2);
#line 1539 "spice-display.c"
	}
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp13_ = channel;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, spice_display_channel_get_type ())) {
#line 1545 "spice-display.c"
		Block52Data* _data52_;
		gint _tmp14_;
		gint _tmp15_;
		GtkWidget* _tmp16_ = NULL;
		SpiceDisplay* _tmp17_;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data52_ = g_slice_new0 (Block52Data);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data52_->_ref_count_ = 1;
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data52_->self = g_object_ref (self);
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp14_ = id;
#line 210 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp14_ != 0) {
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			block52_data_unref (_data52_);
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_data52_ = NULL;
#line 211 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 1567 "spice-display.c"
		}
#line 213 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_display_access_start ((BoxesDisplay*) self);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp15_ = id;
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = boxes_display_get_display ((BoxesDisplay*) self, _tmp15_);
#line 214 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data52_->display = G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp16_) : NULL;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp17_ = _data52_->display;
#line 215 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_data ((GObject*) _tmp17_, "notify::ready", (GCallback) ____lambda90__g_object_notify, block52_data_ref (_data52_), (GClosureNotify) block52_data_unref, 0);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		block52_data_unref (_data52_);
#line 209 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data52_ = NULL;
#line 1585 "spice-display.c"
	}
}


static void ____lambda88__spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda88_ (self, channel);
#line 1593 "spice-display.c"
}


static void ___lambda91_ (BoxesSpiceDisplay* self, SpiceChannel* channel) {
	SpiceChannel* _tmp0_;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_channel_get_type ())) {
#line 1605 "spice-display.c"
		SpiceChannel* _tmp1_;
		SpiceDisplayChannel* _tmp2_;
		SpiceDisplayChannel* display;
		SpiceDisplayChannel* _tmp3_;
		gint _tmp4_ = 0;
		gint _tmp5_;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp1_ = channel;
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_channel_get_type ()) ? ((SpiceDisplayChannel*) _tmp1_) : NULL);
#line 227 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		display = _tmp2_;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = display;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_object_get ((SpiceChannel*) _tmp3_, "channel-id", &_tmp4_, NULL);
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _tmp4_;
#line 228 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "hide", _tmp5_);
#line 229 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_display_access_finish ((BoxesDisplay*) self);
#line 226 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 1630 "spice-display.c"
	}
}


static void ____lambda91__spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda91_ (self, channel);
#line 1638 "spice-display.c"
}


static void boxes_spice_display_real_connect_it (BoxesDisplay* base, GError** error) {
	BoxesSpiceDisplay * self;
	gboolean _tmp0_;
	gulong _tmp1_;
	gulong _tmp4_;
	SpiceSession* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	SpiceSession* _tmp10_;
#line 187 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->connected;
#line 189 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp0_) {
#line 190 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 1659 "spice-display.c"
	}
#line 191 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->connected = TRUE;
#line 193 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->channel_new_id;
#line 196 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp1_ == ((gulong) 0)) {
#line 1669 "spice-display.c"
		SpiceSession* _tmp2_;
		gulong _tmp3_ = 0UL;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = self->priv->session;
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = g_signal_connect_object (_tmp2_, "channel-new", (GCallback) ____lambda88__spice_session_channel_new, self, 0);
#line 197 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->channel_new_id = _tmp3_;
#line 1678 "spice-display.c"
	}
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->channel_destroy_id;
#line 224 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp4_ == ((gulong) 0)) {
#line 1684 "spice-display.c"
		SpiceSession* _tmp5_;
		gulong _tmp6_ = 0UL;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = self->priv->session;
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = g_signal_connect_object (_tmp5_, "channel-destroy", (GCallback) ____lambda91__spice_session_channel_destroy, self, 0);
#line 225 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self->priv->channel_destroy_id = _tmp6_;
#line 1693 "spice-display.c"
	}
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = self->priv->session;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp8_ = boxes_display_get_password ((BoxesDisplay*) self);
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp9_ = _tmp8_;
#line 233 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp7_, "password", _tmp9_, NULL);
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = self->priv->session;
#line 234 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	spice_session_connect (_tmp10_);
#line 1707 "spice-display.c"
}


static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	SpiceSession* _tmp0_;
#line 237 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 238 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	spice_session_disconnect (_tmp0_);
#line 1720 "spice-display.c"
}


static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event) {
	SpiceChannelEvent _tmp0_;
#line 241 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = event;
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_CLOSED:
#line 1734 "spice-display.c"
		{
#line 244 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			self->priv->closed = TRUE;
#line 245 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_signal_emit_by_name ((BoxesDisplay*) self, "disconnected");
#line 246 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 1742 "spice-display.c"
		}
#line 242 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_AUTH:
#line 1746 "spice-display.c"
		{
#line 249 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			boxes_display_set_need_password ((BoxesDisplay*) self, TRUE);
#line 250 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 1752 "spice-display.c"
		}
		default:
		{
#line 253 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 1758 "spice-display.c"
		}
	}
}


static Block53Data* block53_data_ref (Block53Data* _data53_) {
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data53_->_ref_count_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data53_;
#line 1769 "spice-display.c"
}


static void block53_data_unref (void * _userdata_) {
	Block53Data* _data53_;
	_data53_ = (Block53Data*) _userdata_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data53_->_ref_count_)) {
#line 1778 "spice-display.c"
		BoxesSpiceDisplay * self;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data53_->self;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data53_->manager);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block53Data, _data53_);
#line 1788 "spice-display.c"
	}
}


static Block54Data* block54_data_ref (Block54Data* _data54_) {
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data54_->_ref_count_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return _data54_;
#line 1798 "spice-display.c"
}


static void block54_data_unref (void * _userdata_) {
	Block54Data* _data54_;
	_data54_ = (Block54Data*) _userdata_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data54_->_ref_count_)) {
#line 1807 "spice-display.c"
		BoxesSpiceDisplay * self;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		self = _data54_->_data53_->self;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data54_->dev_toggle);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		__vala_SpiceUsbDevice_free0 (_data54_->dev);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		block53_data_unref (_data54_->_data53_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_data54_->_data53_ = NULL;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block54Data, _data54_);
#line 1821 "spice-display.c"
	}
}


static void ___lambda93_ (Block54Data* _data54_, GObject* obj, GAsyncResult* res) {
	Block53Data* _data53_;
	BoxesSpiceDisplay * self;
	GError * _inner_error_ = NULL;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data53_ = _data54_->_data53_;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data53_->self;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (res != NULL);
#line 1836 "spice-display.c"
	{
		SpiceUsbDeviceManager* _tmp0_;
		GAsyncResult* _tmp1_;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _data53_->manager;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp1_ = res;
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 304 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 1848 "spice-display.c"
			goto __catch66_g_error;
		}
	}
	goto __finally66;
	__catch66_g_error:
	{
		GError* err = NULL;
		GtkSwitch* _tmp2_;
		const gchar* _tmp3_ = NULL;
		SpiceUsbDevice* _tmp4_;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_;
		GError* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		err = _inner_error_;
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _data54_->dev_toggle;
#line 306 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		gtk_switch_set_active (_tmp2_, FALSE);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _ ("Error connecting %s: %s");
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = _data54_->dev;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = spice_usb_device_get_description (_tmp4_, "%1$s %2$s");
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _tmp5_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp7_ = err;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_->message;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp9_ = g_strdup_printf (_tmp3_, _tmp6_, _tmp8_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp10_ = _tmp9_;
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp10_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp10_);
#line 307 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp6_);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (err);
#line 1897 "spice-display.c"
	}
	__finally66:
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 303 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		return;
#line 1908 "spice-display.c"
	}
}


static void ____lambda93__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	___lambda93_ (self, source_object, res);
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	block54_data_unref (self);
#line 1918 "spice-display.c"
}


static void _________lambda92_ (Block54Data* _data54_) {
	Block53Data* _data53_;
	BoxesSpiceDisplay * self;
	GtkSwitch* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_data53_ = _data54_->_data53_;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = _data53_->self;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data54_->dev_toggle;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = gtk_switch_get_active (_tmp0_);
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 301 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_) {
#line 1940 "spice-display.c"
		SpiceUsbDeviceManager* _tmp3_;
		SpiceUsbDevice* _tmp4_;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data53_->manager;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = _data54_->dev;
#line 302 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_async (_tmp3_, _tmp4_, NULL, ____lambda93__gasync_ready_callback, block54_data_ref (_data54_));
#line 1949 "spice-display.c"
	} else {
		SpiceUsbDeviceManager* _tmp5_;
		SpiceUsbDevice* _tmp6_;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _data53_->manager;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data54_->dev;
#line 312 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_disconnect_device (_tmp5_, _tmp6_);
#line 1959 "spice-display.c"
	}
}


static void __________lambda92__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_________lambda92_ (self);
#line 1967 "spice-display.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1974 "spice-display.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_list_free (self);
#line 1983 "spice-display.c"
}


static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page, PropertyCreationFlag flags) {
	BoxesSpiceDisplay * self;
	GList* result = NULL;
	GList* list;
	BoxesPropertiesPage _tmp0_;
	GError * _inner_error_ = NULL;
#line 257 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 258 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	list = NULL;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = page;
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 2003 "spice-display.c"
		{
			GtkSwitch* _tmp1_;
			GtkSwitch* toggle;
			SpiceGtkSession* _tmp2_;
			GtkSwitch* _tmp3_;
			GtkSwitch* _tmp4_;
			const gchar* _tmp5_ = NULL;
			GtkSwitch* _tmp6_;
			BoxesProperty* _tmp7_ = NULL;
			BoxesProperty* _tmp8_;
			GtkSwitch* _tmp9_;
			GtkSwitch* _tmp10_;
			GtkSwitch* _tmp11_;
			const gchar* _tmp12_ = NULL;
			GtkSwitch* _tmp13_;
			BoxesProperty* _tmp14_ = NULL;
			BoxesProperty* _tmp15_;
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp1_ = (GtkSwitch*) gtk_switch_new ();
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp1_);
#line 262 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			toggle = _tmp1_;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp2_ = self->priv->gtk_session;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp3_ = toggle;
#line 263 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_object_bind_property_with_closures ((GObject*) _tmp2_, "auto-clipboard", (GObject*) _tmp3_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp4_ = toggle;
#line 265 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_START);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp5_ = _ ("Share clipboard");
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp6_ = toggle;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp7_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp5_, (GtkWidget*) _tmp6_, NULL);
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp8_ = _tmp7_;
#line 266 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp8_);
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp9_ = (GtkSwitch*) gtk_switch_new ();
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp9_);
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (toggle);
#line 268 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			toggle = _tmp9_;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp10_ = toggle;
#line 269 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_object_bind_property_with_closures ((GObject*) self, "resize-guest", (GObject*) _tmp10_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp11_ = toggle;
#line 271 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp11_, GTK_ALIGN_START);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp12_ = _ ("Resize guest");
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp13_ = toggle;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp14_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp12_, (GtkWidget*) _tmp13_, NULL);
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp15_ = _tmp14_;
#line 272 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp15_);
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (toggle);
#line 273 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2077 "spice-display.c"
		}
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2081 "spice-display.c"
		{
			PropertyCreationFlag _tmp16_;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp16_ = flags;
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			if (!((_tmp16_ & PROPERTY_CREATION_FLAG_NO_USB) == PROPERTY_CREATION_FLAG_NO_USB)) {
#line 2088 "spice-display.c"
				GtkSwitch* _tmp17_;
				GtkSwitch* toggle;
				SpiceGtkSession* _tmp18_;
				GtkSwitch* _tmp19_;
				GtkSwitch* _tmp20_;
				const gchar* _tmp21_ = NULL;
				GtkSwitch* _tmp22_;
				BoxesProperty* _tmp23_ = NULL;
				BoxesProperty* _tmp24_;
				gboolean _tmp25_;
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp17_ = (GtkSwitch*) gtk_switch_new ();
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp17_);
#line 277 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				toggle = _tmp17_;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp18_ = self->priv->gtk_session;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp19_ = toggle;
#line 278 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				g_object_bind_property_with_closures ((GObject*) _tmp18_, "auto-usbredir", (GObject*) _tmp19_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp20_ = toggle;
#line 280 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp20_, GTK_ALIGN_START);
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp21_ = _ ("Redirect new USB devices");
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp22_ = toggle;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp23_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp21_, (GtkWidget*) _tmp22_, NULL);
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp24_ = _tmp23_;
#line 281 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (_tmp24_);
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp25_ = self->priv->connected;
#line 283 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (_tmp25_) {
#line 2129 "spice-display.c"
					gboolean found_dev;
#line 284 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					found_dev = FALSE;
#line 2133 "spice-display.c"
					{
						Block53Data* _data53_;
						SpiceSession* _tmp26_;
						SpiceUsbDeviceManager* _tmp27_ = NULL;
						SpiceUsbDeviceManager* _tmp28_;
						SpiceUsbDeviceManager* _tmp29_;
						GPtrArray* _tmp30_ = NULL;
						GPtrArray* devs;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_data53_ = g_slice_new0 (Block53Data);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_data53_->_ref_count_ = 1;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_data53_->self = g_object_ref (self);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp26_ = self->priv->session;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp27_ = spice_usb_device_manager_get (_tmp26_, &_inner_error_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp28_ = _g_object_ref0 (_tmp27_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_data53_->manager = _tmp28_;
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						if (_inner_error_ != NULL) {
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
							block53_data_unref (_data53_);
#line 286 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
							_data53_ = NULL;
#line 2162 "spice-display.c"
							goto __catch65_g_error;
						}
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp29_ = _data53_->manager;
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_tmp30_ = spice_usb_device_manager_get_devices (_tmp29_);
#line 287 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						devs = _tmp30_;
#line 2171 "spice-display.c"
						{
							gint i;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
							i = 0;
#line 2176 "spice-display.c"
							{
								gboolean _tmp31_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
								_tmp31_ = TRUE;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
								while (TRUE) {
#line 2183 "spice-display.c"
									Block54Data* _data54_;
									gboolean _tmp32_;
									gint _tmp34_;
									GPtrArray* _tmp35_;
									gint _tmp36_;
									gint _tmp37_;
									GPtrArray* _tmp38_;
									gint _tmp39_;
									gconstpointer _tmp40_ = NULL;
									SpiceUsbDevice* _tmp41_;
									GtkSwitch* _tmp42_;
									GtkSwitch* _tmp43_;
									gboolean _tmp44_;
									SpiceUsbDevice* _tmp49_;
									gchar* _tmp50_ = NULL;
									gchar* _tmp51_;
									GtkSwitch* _tmp52_;
									BoxesProperty* _tmp53_ = NULL;
									BoxesProperty* _tmp54_;
									GtkSwitch* _tmp55_;
									SpiceUsbDeviceManager* _tmp56_;
									SpiceUsbDevice* _tmp57_;
									gboolean _tmp58_ = FALSE;
									GtkSwitch* _tmp59_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_data54_ = g_slice_new0 (Block54Data);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_data54_->_ref_count_ = 1;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_data54_->_data53_ = block53_data_ref (_data53_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp32_ = _tmp31_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									if (!_tmp32_) {
#line 2218 "spice-display.c"
										gint _tmp33_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_tmp33_ = i;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										i = _tmp33_ + 1;
#line 2224 "spice-display.c"
									}
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp31_ = FALSE;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp34_ = i;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp35_ = devs;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp36_ = g_ptr_array_get_length (_tmp35_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp37_ = _tmp36_;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									if (!(_tmp34_ < _tmp37_)) {
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										block54_data_unref (_data54_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_data54_ = NULL;
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										break;
#line 2244 "spice-display.c"
									}
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp38_ = devs;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp39_ = i;
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp40_ = g_ptr_array_index (_tmp38_, (guint) _tmp39_);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp41_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp40_);
#line 289 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_data54_->dev = _tmp41_;
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp42_ = (GtkSwitch*) gtk_switch_new ();
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									g_object_ref_sink (_tmp42_);
#line 291 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_data54_->dev_toggle = _tmp42_;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp43_ = _data54_->dev_toggle;
#line 292 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									gtk_widget_set_halign ((GtkWidget*) _tmp43_, GTK_ALIGN_START);
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp44_ = found_dev;
#line 294 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									if (!_tmp44_) {
#line 2270 "spice-display.c"
										GtkLabel* _tmp45_;
										GtkLabel* _tmp46_;
										BoxesProperty* _tmp47_ = NULL;
										BoxesProperty* _tmp48_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_tmp45_ = (GtkLabel*) gtk_label_new ("");
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										g_object_ref_sink (_tmp45_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_tmp46_ = _tmp45_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_tmp47_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, "USB devices", (GtkWidget*) _tmp46_, NULL);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_tmp48_ = _tmp47_;
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_g_object_unref0 (_tmp48_);
#line 295 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
										_g_object_unref0 (_tmp46_);
#line 2289 "spice-display.c"
									}
#line 296 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									found_dev = TRUE;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp49_ = _data54_->dev;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp50_ = spice_usb_device_get_description (_tmp49_, "    %1$s %2$s");
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp51_ = _tmp50_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp52_ = _data54_->dev_toggle;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp53_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp51_, (GtkWidget*) _tmp52_, NULL);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp54_ = _tmp53_;
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_g_object_unref0 (_tmp54_);
#line 297 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_g_free0 (_tmp51_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp55_ = _data54_->dev_toggle;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp56_ = _data53_->manager;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp57_ = _data54_->dev;
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp58_ = spice_usb_device_manager_is_device_connected (_tmp56_, _tmp57_);
#line 298 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									gtk_switch_set_active (_tmp55_, _tmp58_);
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_tmp59_ = _data54_->dev_toggle;
#line 300 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									g_signal_connect_data ((GObject*) _tmp59_, "notify::active", (GCallback) __________lambda92__g_object_notify, block54_data_ref (_data54_), (GClosureNotify) block54_data_unref, 0);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									block54_data_unref (_data54_);
#line 288 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
									_data54_ = NULL;
#line 2327 "spice-display.c"
								}
							}
						}
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_ptr_array_unref0 (devs);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						block53_data_unref (_data53_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_data53_ = NULL;
#line 2337 "spice-display.c"
					}
					goto __finally65;
					__catch65_g_error:
					{
						GError* _error_ = NULL;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_error_ = _inner_error_;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_inner_error_ = NULL;
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_error_free0 (_error_);
#line 2349 "spice-display.c"
					}
					__finally65:
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					if (_inner_error_ != NULL) {
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						_g_object_unref0 (toggle);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						__g_list_free__g_object_unref0_0 (list);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						g_clear_error (&_inner_error_);
#line 285 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
						return NULL;
#line 2364 "spice-display.c"
					}
				}
#line 276 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (toggle);
#line 2369 "spice-display.c"
			}
#line 320 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			break;
#line 2373 "spice-display.c"
		}
		default:
#line 260 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 2378 "spice-display.c"
	}
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = list;
#line 323 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2384 "spice-display.c"
}


static const gchar* boxes_spice_display_real_get_protocol (BoxesDisplay* base) {
	const gchar* result;
	BoxesSpiceDisplay* self;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = "SPICE";
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2397 "spice-display.c"
}


static gchar* boxes_spice_display_real_get_uri (BoxesDisplay* base) {
	gchar* result;
	BoxesSpiceDisplay* self;
	SpiceSession* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "uri", &_tmp1_, NULL);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp2_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2419 "spice-display.c"
}


GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self) {
	GByteArray* result;
	SpiceSession* _tmp0_;
	GByteArray* _tmp1_ = NULL;
	GByteArray* _tmp2_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "ca", &_tmp1_, NULL);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp2_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2440 "spice-display.c"
}


void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value) {
	SpiceSession* _tmp0_;
	GByteArray* _tmp1_;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = value;
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "ca", _tmp1_, NULL);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_notify ((GObject *) self, "ca-cert");
#line 2457 "spice-display.c"
}


gboolean boxes_spice_display_get_resize_guest (BoxesSpiceDisplay* self) {
	gboolean result;
	gboolean _tmp0_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->_resize_guest;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	result = _tmp0_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return result;
#line 2472 "spice-display.c"
}


void boxes_spice_display_set_resize_guest (BoxesSpiceDisplay* self, gboolean value) {
	gboolean _tmp0_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = value;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->_resize_guest = _tmp0_;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_notify ((GObject *) self, "resize-guest");
#line 2486 "spice-display.c"
}


static void _boxes_spice_display____lambda94_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err) {
	GError* _tmp0_;
	const gchar* _tmp1_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = err;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_->message;
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp1_);
#line 2501 "spice-display.c"
}


static void __boxes_spice_display____lambda94__spice_usb_device_manager_auto_connect_failed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self) {
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display____lambda94_ (self, device, _error_);
#line 2508 "spice-display.c"
}


static void _boxes_spice_display____lambda95_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err) {
	GError* _tmp0_;
	const gchar* _tmp1_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = err;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_->message;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp1_);
#line 2523 "spice-display.c"
}


static void __boxes_spice_display____lambda95__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self) {
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display____lambda95_ (self, device, _error_);
#line 2530 "spice-display.c"
}


static void _boxes_spice_display___lambda96_ (BoxesSpiceDisplay* self) {
	BoxesBoxConfig* _tmp0_;
	BoxesBoxConfig* _tmp1_;
	SpiceGtkSession* _tmp2_;
	BoxesBoxConfigSyncProperty* _tmp3_;
	gint _tmp3__length1;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = self->priv->gtk_session;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->gtk_session_sync_properties;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3__length1 = self->priv->gtk_session_sync_properties_length1;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_box_config_sync_properties (_tmp1_, (GObject*) _tmp2_, _tmp3_, _tmp3__length1);
#line 2552 "spice-display.c"
}


static void __boxes_spice_display___lambda96__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display___lambda96_ (self);
#line 2559 "spice-display.c"
}


static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_ui_state_changed (self);
#line 2566 "spice-display.c"
}


static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSpiceDisplay * self;
	gchar* _tmp0_;
	GValue _tmp1_ = {0};
	BoxesBoxConfigSyncProperty _tmp2_ = {0};
	BoxesBoxConfigSyncProperty* _tmp3_ = NULL;
	gchar* _tmp4_;
	GValue _tmp5_ = {0};
	BoxesBoxConfigSyncProperty _tmp6_ = {0};
	gchar* _tmp7_;
	GValue _tmp8_ = {0};
	BoxesBoxConfigSyncProperty _tmp9_ = {0};
	BoxesBoxConfigSyncProperty* _tmp10_ = NULL;
	SpiceSession* _tmp11_;
	SpiceSession* _tmp12_;
	SpiceAudio* _tmp13_ = NULL;
	SpiceSession* _tmp14_;
	SpiceGtkSession* _tmp15_ = NULL;
	BoxesApp* _tmp21_;
	GError * _inner_error_ = NULL;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	parent_class = G_OBJECT_CLASS (boxes_spice_display_parent_class);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_strdup ("resize-guest");
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp1_, G_TYPE_BOOLEAN);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp1_, TRUE);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	memset (&_tmp2_, 0, sizeof (BoxesBoxConfigSyncProperty));
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp2_.name);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_.name = _tmp0_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp2_.default_value) ? (g_value_unset (&_tmp2_.default_value), NULL) : NULL;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_.default_value = _tmp1_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_new0 (BoxesBoxConfigSyncProperty, 1);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp3_[0] = _tmp2_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->display_sync_properties, self->priv->display_sync_properties_length1), NULL);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties = _tmp3_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties_length1 = 1;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->_display_sync_properties_size_ = self->priv->display_sync_properties_length1;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_strdup ("auto-clipboard");
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp5_, G_TYPE_BOOLEAN);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp5_, TRUE);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	memset (&_tmp6_, 0, sizeof (BoxesBoxConfigSyncProperty));
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp6_.name);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_.name = _tmp4_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp6_.default_value) ? (g_value_unset (&_tmp6_.default_value), NULL) : NULL;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_.default_value = _tmp5_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = g_strdup ("auto-usbredir");
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp8_, G_TYPE_BOOLEAN);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp8_, FALSE);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	memset (&_tmp9_, 0, sizeof (BoxesBoxConfigSyncProperty));
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp9_.name);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp9_.name = _tmp7_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp9_.default_value) ? (g_value_unset (&_tmp9_.default_value), NULL) : NULL;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp9_.default_value = _tmp8_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = g_new0 (BoxesBoxConfigSyncProperty, 2);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_[0] = _tmp6_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_[1] = _tmp9_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->gtk_session_sync_properties, self->priv->gtk_session_sync_properties_length1), NULL);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = _tmp10_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties_length1 = 2;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->_gtk_session_sync_properties_size_ = self->priv->gtk_session_sync_properties_length1;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_display_set_need_password ((BoxesDisplay*) self, FALSE);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp11_ = spice_session_new ();
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->session = _tmp11_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp12_ = self->priv->session;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp13_ = spice_audio_get (_tmp12_, NULL);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->audio = _tmp13_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp14_ = self->priv->session;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp15_ = spice_gtk_session_get (_tmp14_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session = _tmp15_;
#line 2692 "spice-display.c"
	{
		SpiceSession* _tmp16_;
		SpiceUsbDeviceManager* _tmp17_ = NULL;
		SpiceUsbDeviceManager* _tmp18_;
		SpiceUsbDeviceManager* manager;
		SpiceUsbDeviceManager* _tmp19_;
		SpiceUsbDeviceManager* _tmp20_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = self->priv->session;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp17_ = spice_usb_device_manager_get (_tmp16_, &_inner_error_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _g_object_ref0 (_tmp17_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		manager = _tmp18_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 2710 "spice-display.c"
			goto __catch67_g_error;
		}
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp19_ = manager;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp19_, "auto-connect-failed", (GCallback) __boxes_spice_display____lambda94__spice_usb_device_manager_auto_connect_failed, self, 0);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp20_ = manager;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp20_, "device-error", (GCallback) __boxes_spice_display____lambda95__spice_usb_device_manager_device_error, self, 0);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 2723 "spice-display.c"
	}
	goto __finally67;
	__catch67_g_error:
	{
		GError* _error_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 2735 "spice-display.c"
	}
	__finally67:
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 2744 "spice-display.c"
	}
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) self, "notify::config", (GCallback) __boxes_spice_display___lambda96__g_object_notify, self, 0);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp21_ = boxes_app_app;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) _tmp21_, "notify::ui-state", (GCallback) _boxes_spice_display_ui_state_changed_g_object_notify, self, 0);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return obj;
#line 2754 "spice-display.c"
}


static void boxes_spice_display_class_init (BoxesSpiceDisplayClass * klass) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_parent_class = g_type_class_peek_parent (klass);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_type_class_add_private (klass, sizeof (BoxesSpiceDisplayPrivate));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_display = boxes_spice_display_real_get_display;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->should_keep_alive = boxes_spice_display_real_should_keep_alive;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->set_enable_audio = boxes_spice_display_real_set_enable_audio;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->set_enable_inputs = boxes_spice_display_real_set_enable_inputs;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_pixbuf = boxes_spice_display_real_get_pixbuf;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->collect_logs = boxes_spice_display_real_collect_logs;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->connect_it = boxes_spice_display_real_connect_it;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->disconnect_it = boxes_spice_display_real_disconnect_it;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_properties = boxes_spice_display_real_get_properties;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_protocol = boxes_spice_display_real_get_protocol;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_uri = boxes_spice_display_real_get_uri;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_spice_display_get_property;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_spice_display_set_property;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_spice_display_constructor;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_spice_display_finalize;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_PROTOCOL, g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_CA_CERT, g_param_spec_boxed ("ca-cert", "ca-cert", "ca-cert", G_TYPE_BYTE_ARRAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_RESIZE_GUEST, g_param_spec_boolean ("resize-guest", "resize-guest", "resize-guest", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2801 "spice-display.c"
}


static void boxes_spice_display_instance_init (BoxesSpiceDisplay * self) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv = BOXES_SPICE_DISPLAY_GET_PRIVATE (self);
#line 2808 "spice-display.c"
}


static void boxes_spice_display_finalize (GObject* obj) {
	BoxesSpiceDisplay * self;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 15 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->display_sync_properties, self->priv->display_sync_properties_length1), NULL);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->gtk_session_sync_properties, self->priv->gtk_session_sync_properties_length1), NULL);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->main_channel);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (boxes_spice_display_parent_class)->finalize (obj);
#line 2828 "spice-display.c"
}


GType boxes_spice_display_get_type (void) {
	static volatile gsize boxes_spice_display_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_spice_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSpiceDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_spice_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSpiceDisplay), 0, (GInstanceInitFunc) boxes_spice_display_instance_init, NULL };
		GType boxes_spice_display_type_id;
		boxes_spice_display_type_id = g_type_register_static (BOXES_TYPE_DISPLAY, "BoxesSpiceDisplay", &g_define_type_info, 0);
		g_once_init_leave (&boxes_spice_display_type_id__volatile, boxes_spice_display_type_id);
	}
	return boxes_spice_display_type_id__volatile;
}


static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_PROTOCOL:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_value_set_string (value, boxes_display_get_protocol ((BoxesDisplay*) self));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_URI:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_value_take_string (value, boxes_display_get_uri ((BoxesDisplay*) self));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_value_take_boxed (value, boxes_spice_display_get_ca_cert (self));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_RESIZE_GUEST:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		g_value_set_boolean (value, boxes_spice_display_get_resize_guest (self));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 2873 "spice-display.c"
		default:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 2879 "spice-display.c"
	}
}


static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_ca_cert (self, g_value_get_boxed (value));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_RESIZE_GUEST:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_resize_guest (self, g_value_get_boolean (value));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 2901 "spice-display.c"
		default:
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		break;
#line 2907 "spice-display.c"
	}
}


static gint* _int_dup (gint* self) {
	gint* dup;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	dup = g_new0 (gint, 1);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	memcpy (dup, self, sizeof (gint));
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return dup;
#line 2920 "spice-display.c"
}


static gpointer __int_dup0 (gpointer self) {
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	return self ? _int_dup (self) : NULL;
#line 2927 "spice-display.c"
}


void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error) {
	gint* _vala_port = NULL;
	gint* _vala_tls_port = NULL;
	const gchar* _tmp0_;
	xmlURI* _tmp1_ = NULL;
	xmlURI* uri;
	xmlURI* _tmp2_;
	gint _tmp5_;
	gint* _tmp6_;
	xmlURI* _tmp7_;
	gint _tmp8_;
	gint* _tmp9_;
	xmlURI* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* query_str;
	const gchar* _tmp20_;
	gboolean _tmp44_ = FALSE;
	gint* _tmp45_;
	gboolean _tmp47_;
	GError * _inner_error_ = NULL;
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp0_ = uri_as_text;
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 331 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	uri = _tmp1_;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp2_ = uri;
#line 333 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 2968 "spice-display.c"
		const gchar* _tmp3_ = NULL;
		GError* _tmp4_;
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _ ("Invalid URI");
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp4_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp3_);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = _tmp4_;
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_propagate_error (error, _inner_error_);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 2985 "spice-display.c"
		} else {
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 334 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 2995 "spice-display.c"
		}
	}
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp5_ = 0;
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp6_ = __int_dup0 (&_tmp5_);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_tls_port);
#line 336 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_vala_tls_port = _tmp6_;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp7_ = uri;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp8_ = _tmp7_->port;
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp9_ = __int_dup0 (&_tmp8_);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_port);
#line 337 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_vala_port = _tmp9_;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp10_ = uri;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _tmp10_->query_raw;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp13_ = _tmp12_;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp14_ = _tmp13_;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp14_ == NULL) {
#line 3028 "spice-display.c"
		xmlURI* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp15_ = uri;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_->query;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp17_ = g_strdup (_tmp16_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp13_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp13_ = _tmp17_;
#line 3042 "spice-display.c"
	}
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp18_ = _tmp13_;
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp19_ = g_strdup (_tmp18_);
#line 338 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	query_str = _tmp19_;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp20_ = query_str;
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp20_ != NULL) {
#line 3054 "spice-display.c"
		const gchar* _tmp21_;
		BoxesQuery* _tmp22_;
		BoxesQuery* query;
		BoxesQuery* _tmp23_;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_;
		gboolean _tmp26_;
		BoxesQuery* _tmp35_;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_;
		gboolean _tmp38_;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp21_ = query_str;
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp22_ = boxes_query_new (_tmp21_);
#line 341 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		query = _tmp22_;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp23_ = query;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp24_ = boxes_query_get (_tmp23_, "port");
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp25_ = _tmp24_;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp26_ = _tmp25_ != NULL;
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp25_);
#line 342 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp26_) {
#line 3084 "spice-display.c"
			gint* _tmp27_;
			BoxesQuery* _tmp30_;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_;
			gint _tmp33_ = 0;
			gint* _tmp34_;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp27_ = _vala_port;
#line 343 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			if ((*_tmp27_) > 0) {
#line 3095 "spice-display.c"
				const gchar* _tmp28_ = NULL;
				GError* _tmp29_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp28_ = _ ("The port must be specified once");
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_tmp29_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp28_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				_inner_error_ = _tmp29_;
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					g_propagate_error (error, _inner_error_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_free0 (_tmp13_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					return;
#line 3118 "spice-display.c"
				} else {
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_g_free0 (_tmp13_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					g_clear_error (&_inner_error_);
#line 344 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
					return;
#line 3134 "spice-display.c"
				}
			}
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp30_ = query;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp31_ = boxes_query_get (_tmp30_, "port");
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp32_ = _tmp31_;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp33_ = atoi (_tmp32_);
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp34_ = __int_dup0 (&_tmp33_);
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_port);
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_vala_port = _tmp34_;
#line 345 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp32_);
#line 3153 "spice-display.c"
		}
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp35_ = query;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp36_ = boxes_query_get (_tmp35_, "tls-port");
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp37_ = _tmp36_;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp38_ = _tmp37_ != NULL;
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp37_);
#line 348 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_tmp38_) {
#line 3167 "spice-display.c"
			BoxesQuery* _tmp39_;
			gchar* _tmp40_ = NULL;
			gchar* _tmp41_;
			gint _tmp42_ = 0;
			gint* _tmp43_;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp39_ = query;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp40_ = boxes_query_get (_tmp39_, "tls-port");
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp41_ = _tmp40_;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp42_ = atoi (_tmp41_);
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_tmp43_ = __int_dup0 (&_tmp42_);
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_tls_port);
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_vala_tls_port = _tmp43_;
#line 349 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp41_);
#line 3189 "spice-display.c"
		}
#line 340 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (query);
#line 3193 "spice-display.c"
	}
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp45_ = _vala_port;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if ((*_tmp45_) <= 0) {
#line 3199 "spice-display.c"
		gint* _tmp46_;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp46_ = _vala_tls_port;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp44_ = (*_tmp46_) <= 0;
#line 3205 "spice-display.c"
	} else {
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp44_ = FALSE;
#line 3209 "spice-display.c"
	}
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_tmp47_ = _tmp44_;
#line 352 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (_tmp47_) {
#line 3215 "spice-display.c"
		const gchar* _tmp48_ = NULL;
		GError* _tmp49_;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp48_ = _ ("Missing port in Spice URI");
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_tmp49_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp48_);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_inner_error_ = _tmp49_;
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_propagate_error (error, _inner_error_);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (query_str);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp13_);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 3236 "spice-display.c"
		} else {
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (query_str);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp13_);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 353 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
			return;
#line 3250 "spice-display.c"
		}
	}
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (query_str);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp13_);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	_xmlFreeURI0 (uri);
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (port) {
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		*port = _vala_port;
#line 3263 "spice-display.c"
	} else {
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_port);
#line 3267 "spice-display.c"
	}
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
	if (tls_port) {
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		*tls_port = _vala_tls_port;
#line 3273 "spice-display.c"
	} else {
#line 328 "/extra-data/checkout/gnome/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_tls_port);
#line 3277 "spice-display.c"
	}
}



